package com.ruoyi.baseinfo.mapper;

import java.util.List;
import com.ruoyi.baseinfo.domain.BaseGroupInfo;

/**
 * 班组基础信息Mapper接口
 * 
 * @author CasearBao
 * @date 2020-10-21
 */
public interface BaseGroupInfoMapper 
{
    /**
     * 查询班组基础信息
     * 
     * @param objid 班组基础信息ID
     * @return 班组基础信息
     */
    public BaseGroupInfo selectBaseGroupInfoById(Long objid);

    /**
     * 查询班组基础信息列表
     * 
     * @param baseGroupInfo 班组基础信息
     * @return 班组基础信息集合
     */
    public List<BaseGroupInfo> selectBaseGroupInfoList(BaseGroupInfo baseGroupInfo);

    /**
     * 新增班组基础信息
     * 
     * @param baseGroupInfo 班组基础信息
     * @return 结果
     */
    public int insertBaseGroupInfo(BaseGroupInfo baseGroupInfo);

    /**
     * 修改班组基础信息
     * 
     * @param baseGroupInfo 班组基础信息
     * @return 结果
     */
    public int updateBaseGroupInfo(BaseGroupInfo baseGroupInfo);

    /**
     * 删除班组基础信息
     * 
     * @param objid 班组基础信息ID
     * @return 结果
     */
    public int deleteBaseGroupInfoById(Long objid);

    /**
     * 批量删除班组基础信息
     * 
     * @param objids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBaseGroupInfoByIds(String[] objids);
}
